import { logger } from '@reskript/core';
import semver from 'semver';
import { run as v2 } from './v2/index.js';
import { run as v3 } from './v3/index.js';
import { run as v4 } from './v4/index.js';
import { run as v6 } from './v6/index.js';
import { readAllDependencies } from './utils.js';
const resolveCurrentVersion = async (cwd) => {
    const dependencies = await readAllDependencies(cwd);
    const entries = Object.entries(dependencies);
    const maxVersion = entries.filter(([name]) => name.startsWith('@reskript/')).reduce((maxVersion, entry) => {
        var _a, _b;
        const versionRange = entry[1];
        return Math.max((_b = (_a = semver.minVersion(versionRange)) === null || _a === void 0 ? void 0 : _a.major) !== null && _b !== void 0 ? _b : 0, maxVersion);
    }, 0);
    return maxVersion;
};
export const run = async (cwd) => {
    const currentVersion = await resolveCurrentVersion(cwd);
    switch (currentVersion) {
        case 0:
            logger.error('Unable to find any @reskript/* packages in current working directory.');
            process.exit(13);
            break;
        case 1:
            await v2(cwd);
            break;
        case 2:
            await v3(cwd);
            break;
        case 3:
            await v4(cwd);
            break;
        case 4:
            logger.error('Version 5 is fully compatible with V4, feel safe to go on');
            break;
        case 5:
            await v6(cwd);
            break;
        case 6:
            logger.log('You have already installed the latest verion');
            break;
        default:
            logger.log(`We don't have a policy to migrate current installed version ${currentVersion}`);
            break;
    }
};
