import path from 'node:path';
import fs from 'node:fs/promises';
import { warn, tip } from '../logger.js';
import { importClientSettings } from '../utils.js';
// eslint-disable-next-line complexity
export default async (cwd) => {
    var _a, _b, _c, _d, _e, _f;
    const settings = await importClientSettings(cwd);
    if (!settings) {
        return;
    }
    warn('reskript config has been changed to .ts (recommended) or .mjs and is written in ESM', 'see: https://reskript.dev/docs/migration/v4#项目配置文件');
    if (((_b = (_a = settings.build) === null || _a === void 0 ? void 0 : _a.finalize) === null || _b === void 0 ? void 0 : _b.length) === 3) {
        warn('all functions in internals argument of build.finalize has been changed to async', 'see: https://reskript.dev/docs/migration/v4#finalize函数异步化');
    }
    const settingsContent = await fs.readFile(path.join(cwd, 'reskript.config.js'), 'utf-8');
    if (settingsContent.includes('postCSS') || settingsContent.includes('postCSSModules')) {
        warn('loader postCSS and postCSSModules has been renamed to postcss', 'see: https://reskript.dev/docs/migration/v4#loader命名修改');
    }
    if (settingsContent.includes('from \'@reskript/config-webpack\'')) {
        warn('@reskript/config-webpack no longer exports loaders and rules, use child modules instead', 'see: https://reskript.dev/docs/migration/v4#config-webpack导出变更');
    }
    if (settingsContent.includes('require(')) {
        warn('found require() call in you reskript.config.js, which is not allowed by ESM', 'see: https://reskript.dev/docs/migration/v4#项目配置文件');
    }
    if (settingsContent.includes('__dirname' || settingsContent.includes('__filename'))) {
        warn('found __dirname or __filename in you reskript.config.js, which is not allowed by ESM', 'see: https://reskript.dev/docs/migration/v4#项目配置文件');
    }
    if (settingsContent.includes('require.resolve(')) {
        warn('found require.resolve() call in you reskript.config.js, which is not allowed by ESM', 'see: https://reskript.dev/docs/migration/v4#项目配置文件');
    }
    if (typeof ((_c = settings.build) === null || _c === void 0 ? void 0 : _c.finalize) === 'function') {
        tip('build.finalize in reskript.config.js can be async now', 'see: https://reskript.dev/docs/migration/v4#finalize函数异步化');
    }
    if (typeof ((_d = settings.devServer) === null || _d === void 0 ? void 0 : _d.finalize) === 'function') {
        tip('devServer.finalize in reskript.config.js can be async now', 'see: https://reskript.dev/docs/migration/v4#finalize函数异步化');
    }
    if (typeof ((_f = (_e = settings.build) === null || _e === void 0 ? void 0 : _e.script) === null || _f === void 0 ? void 0 : _f.finalize) === 'function') {
        tip('build.script.finalize in reskript.config.js can be async now', 'see: https://reskript.dev/docs/migration/v4#finalize函数异步化');
    }
};
